## Ansættelseskontrakt

Mellem undertegnede

<company-name>Nordic Software Solutions ApS, CVR-nr. 35298741, Vesterbrogade 68, 2. th., 4460 Snertinge</company-name>

og

## Frederik Madsen  
Sankt Jørgens Allé 15, 4. tv., 8781 Stenderup (herefter kaldet medarbejderen)

indgås følgende:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder sin ansættelse den 1. august 2024.
</start-date>

<location>
## [SECTION-IDX]. Arbejdssted

Medarbejderens faste arbejdssted er Vesterbrogade 68, 2. th., 2605 Brøndby.
</location>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen er ansat som Softwareudvikler.
</title>

## [SECTION-IDX]. Arbejdsopgaver

Medarbejderen skal primært beskæftige sig med udvikling og vedligeholdelse af softwareapplikationer, fejlsøgning og deltagelse i teammøder og kodegennemgange. Opgaverne kan justeres efter virksomhedens løbende behov.

<trial-period>
Ansættelsen er ikke omfattet af en prøvetid.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den årlige løn udgør kr. 600.000 brutto (før skat, pension og lovpligtige bidrag) og udbetales månedsvis bagud med kr. 50.000 brutto pr. måned. Lønnen overføres til medarbejderens konto senest sidste hverdag i måneden.

Lønnen revurderes én gang årligt pr. 1. oktober.
</salary>

<pension>
## [SECTION-IDX]. Pension

Der oprettes pensionsordning hos Danica Pension. Arbejdsgiver indbetaler 8 %, og medarbejderen 4 % af den faste løn som pensionsbidrag.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler samtlige påkrævede sociale sikringsbidrag i henhold til gældende dansk lovgivning, herunder ATP, barselsfond og andre relevante bidrag.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den gennemsnitlige ugentlige arbejdstid er 37 timer. Arbejdstiden placeres indenfor virksomhedens faste rammer og aftales nærmere med nærmeste leder.

Lønnen er inklusiv betaling for eventuelt merarbejde af begrænset omfang. Pålagt overarbejde kan efter forudgående aftale honoreres med afspadsering eller ekstra betaling.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen optjener og afholder ferie med løn i henhold til ferielovens regler. Særligt ferietillæg på 2,48 % af den ferieberettigede løn udbetales.

Juleaftensdag og nytårsaftensdag betragtes som fridage med løn.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Ekstra feriefridage

Der ydes én ekstra uge med feriefridage (5 dage) pr. ferieår ud over den ferie, der følger af ferieloven. Feriefridagene kan enten afholdes eller efter nærmere aftale overføres til næste ferieår. Ikke afholdte dage udbetales ved fratrædelse.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har ret til at deltage i relevant efter- og videreuddannelse i overensstemmelse med virksomhedens og overenskomstens bestemmelser. Uddannelse aftales løbende mellem medarbejderen og ledelsen.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom skal medarbejderen melde fravær til nærmeste leder snarest muligt. Virksomheden kan anmode om dokumentation fra læge efter tre sygedage. Omkostninger til lægeattest afholdes af virksomheden.

Medarbejderen oppebærer fuld sædvanlig løn under sygdom.
</illness>

<parental-leave>
## [SECTION-IDX]. Graviditet, barsel og forældreorlov

Medarbejderen har ret til orlov ved graviditet, barsel eller adoption i overensstemmelse med gældende lovgivning.

- Mor har ret til fuld løn i 4 uger før forventet fødsel og 14 uger efter fødslen.
- Far/medmor har ret til fuld løn i 2 uger efter fødslen.

Retten til løn under orlov gælder også ved adoption, hvis autoriteterne kræver tilstedeværelse før modtagelse af barnet.

Ved barns sygdom har medarbejderen ret til frihed med løn i op til 5 arbejdsdage pr. barn pr. år til pasning af sygt barn under 18 år.
</parental-leave>

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan opsiges af begge parter med 90 dages varsel til udgangen af en måned.

Opsigelse skal ske skriftligt, og være modtageren i hænde senest den sidste dag i måneden.

Ved opsigelse finder funktionærloven anvendelse i det omfang, den ikke er fraveget til fordel for medarbejderen.
</termination>

<collective-agreement>
## [SECTION-IDX]. Kollektiv overenskomst

Ansættelsesforholdet er omfattet af IT-overenskomsten (Prosa).
</collective-agreement>

## [SECTION-IDX]. Fortrolighed og loyalitet

Medarbejderen er pålagt tavshedspligt angående forhold, der omhandler virksomhedens forretningshemmeligheder og øvrige fortrolige oplysninger, både under og efter ansættelsen. Videregivelse af sådanne oplysninger til tredjemand er ikke tilladt uden forudgående skriftlig tilladelse.

## [SECTION-IDX]. Retsgrundlag

Ansættelsesforholdet er reguleret af dansk ret. Hvor ovenstående ikke stiller medarbejderen bedre, gælder funktionær- og ferielovens almindelige regler.

Snertinge, den 4. juli 2024

Medarbejderen _____________________________________

Virksomheden _____________________________________